@@ -830,8 +830,11 @@ get_changed_tasks (ECalBackendExchange *cbex)
 					modtime, icalcomp);
 			e_cal_backend_exchange_cache_unlock (cbex);
 
-			if (status && kind == ICAL_VTODO_COMPONENT)
-				e_cal_backend_notify_object_created (E_CAL_BACKEND (cbex), icalcomponent_as_ical_string (icalcomp));
+			if (status && kind == ICAL_VTODO_COMPONENT) {
+				char *str = icalcomponent_as_ical_string (icalcomp);
+				e_cal_backend_notify_object_created (E_CAL_BACKEND (cbex), str);
+				g_free (str);
+			}
 
 		}
 	} /* End while */
@@ -1326,8 +1329,8 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
                 return GNOME_Evolution_Calendar_InvalidObject;
 
 	for (l = comps; l; l = l->next) {
-                const char *uid, *rid;
-                char *calobj;
+                const char *uid;
+                char *obj, *rid = NULL;
 
                 subcomp = l->data;
 
@@ -1342,6 +1345,7 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 
 		e_cal_component_get_uid (ecalcomp, &uid);
                 rid = e_cal_component_get_recurid_as_string (ecalcomp);
+		obj = (char *) e_cal_component_get_as_string (ecalcomp);
 
                 /*see if the object is there in the cache. if found, modify object, else create object*/
 
@@ -1350,23 +1354,29 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
                         char *old_object;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
-                        status = modify_task_object (backend, cal, calobj, CALOBJ_MOD_THIS, &old_object, NULL);
-                        if (status != GNOME_Evolution_Calendar_Success)
+                        status = modify_task_object (backend, cal, obj, CALOBJ_MOD_THIS, &old_object, NULL);
+                        if (status != GNOME_Evolution_Calendar_Success) {
+				g_free (rid);
                                 goto error;
+			}
 
-                        e_cal_backend_notify_object_modified (E_CAL_BACKEND (backend), old_object, calobj);
+                        e_cal_backend_notify_object_modified (E_CAL_BACKEND (backend), old_object, obj);
 			g_free (old_object);
                 } else {
                         char *returned_uid;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
-			calobj = (char *) icalcomponent_as_ical_string (subcomp);
-			status = create_task_object (backend, cal, &calobj, &returned_uid);
-                        if (status != GNOME_Evolution_Calendar_Success)
+			status = create_task_object (backend, cal, &obj, &returned_uid);
+                        if (status != GNOME_Evolution_Calendar_Success) {
+				g_free (obj);
+				g_free (rid);
                                 goto error;
+			}
 
-                        e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), calobj);
+                        e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), obj);
+			g_free (obj);
                 }
+		g_free (rid);
         }
 
         g_list_free (comps);
