@@ -25,7 +25,8 @@
 
 #include <string.h>
 
-#include <camel/camel-i18n.h>
+#include <glib/gi18n-lib.h>
+
 #include <camel/camel-provider.h>
 #include <camel/camel-session.h>
 #include <camel/camel-url.h>
@@ -62,8 +63,6 @@ CamelProviderConfEntry exchange_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "generals", NULL,
 	  N_("Options") },
-        { CAMEL_PROVIDER_CONF_CHECKBOX, "check_all", NULL,
-          N_("C_heck for new messages in all folders"), "0" },
 	{ CAMEL_PROVIDER_CONF_CHECKSPIN, "passwd_exp_warn_period", NULL,
 	  N_("_Password Expiry Warning period: %s"), "y:1:7:90" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "sync_offline", NULL,
@@ -77,7 +76,7 @@ CamelProviderConfEntry exchange_conf_entries[] = {
 	  N_("Only check for Junk messag_es in the Inbox folder"), "0" },
 	{ CAMEL_PROVIDER_CONF_HIDDEN, "auth-domain", NULL,
 	  NULL, "Exchange" },
-	 	
+
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
 };
@@ -95,7 +94,7 @@ static CamelProvider exchange_provider = {
 
 	CAMEL_URL_NEED_USER | CAMEL_URL_HIDDEN_AUTH | CAMEL_URL_HIDDEN_HOST,
 
-	exchange_conf_entries 
+	exchange_conf_entries
 
 	/* ... */
 };
