@@ -126,6 +126,9 @@ init (CamelExchangeStore *exch, CamelExchangeStoreClass *klass)
 
 	store->flags |= CAMEL_STORE_SUBSCRIPTIONS;
 	store->flags &= ~(CAMEL_STORE_VTRASH | CAMEL_STORE_VJUNK);
+	/* FIXME: Like the GroupWise provider, Exchange should also 
+	have its own EXCAHNGE_JUNK flags so as to rightly handle
+	the actual Junk & Trash folders */
 
 	exch->connect_lock = g_mutex_new ();
 }
@@ -289,9 +292,6 @@ construct (CamelService *service, CamelSession *session,
 	if (!(exch->storage_path = camel_session_get_storage_path (session, service, ex)))
 		return;
 
-	if (camel_url_get_param (url, "filter_junk"))
-		CAMEL_STORE (service)->flags |= CAMEL_STORE_VJUNK;
-
 	exch->stub = NULL;
 }
 
@@ -347,17 +347,17 @@ static void
 camel_exchange_get_password (CamelService *service, CamelException *ex)
 {
 	CamelSession *session = camel_service_get_session (service);
-	char *prompt, *account_name;
 
 	if (!service->url->passwd) {
-		/* This is a hack to use the same string being used in
-		   exchange-account.c:get_password */
-		account_name = g_strdup_printf ("%s@%s", service->url->user, service->url->host);
-		prompt = g_strdup_printf (_("%sEnter password for %s"), "", account_name);
+		gchar *prompt;
+
+		prompt = camel_session_build_password_prompt (
+			"Exchange", service->url->user, service->url->host);
+
+		service->url->passwd = camel_session_get_password (
+			session, service, "Exchange", prompt,
+			"password", CAMEL_SESSION_PASSWORD_SECRET, ex);
 
-		service->url->passwd = camel_session_get_password (session,
-					service, "Exchange", prompt, "password", CAMEL_SESSION_PASSWORD_SECRET, ex);
-		g_free (account_name);
 		g_free (prompt);
 	}
 }
@@ -376,6 +376,14 @@ camel_exchange_forget_password (CamelService *service, CamelException *ex)
 	}
 }
 
+static void
+update_camel_stub (gpointer folder_name, gpointer folder, gpointer user_data)
+{
+	CamelExchangeFolder *exch_folder = CAMEL_EXCHANGE_FOLDER (folder);
+	if (exch_folder)
+		exch_folder->stub = (CamelStub *)user_data;
+}
+
 static gboolean
 exchange_connect (CamelService *service, CamelException *ex)
 {
@@ -421,6 +429,8 @@ exchange_connect (CamelService *service, CamelException *ex)
 	if (online_mode) {
 		camel_exchange_get_password (service, ex);
 		if (camel_exception_is_set (ex)) {
+			camel_object_unref (exch->stub);
+			exch->stub = NULL;
 			g_mutex_unlock (exch->connect_lock);
 			return FALSE;
 		}
@@ -447,12 +457,16 @@ exchange_connect (CamelService *service, CamelException *ex)
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     _("Could not authenticate to server. "
 				       "(Password incorrect?)\n\n"));
+		camel_object_unref (exch->stub);
+		exch->stub = NULL;
 		g_mutex_unlock (exch->connect_lock);
 		return FALSE;
 	} else {
 		exch->stub_connected = TRUE;
 	}
 
+	g_hash_table_foreach (exch->folders, update_camel_stub, exch->stub);
+	
 	g_mutex_unlock (exch->connect_lock);
 
 	return TRUE;
@@ -461,6 +475,13 @@ exchange_connect (CamelService *service, CamelException *ex)
 static gboolean
 exchange_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 {
+
+	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (service);
+	
+	if (exch->stub) {
+		exch->stub = NULL;
+	}
+	
 	return TRUE;
 }
 
